aboutsummaryrefslogtreecommitdiffstats
path: root/routers/web/feed/convert.go
diff options
context:
space:
mode:
Diffstat (limited to 'routers/web/feed/convert.go')
-rw-r--r--routers/web/feed/convert.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/routers/web/feed/convert.go b/routers/web/feed/convert.go
index 3a2de1d9a1..3defa436a7 100644
--- a/routers/web/feed/convert.go
+++ b/routers/web/feed/convert.go
@@ -64,7 +64,7 @@ func renderMarkdown(ctx *context.Context, act *activities_model.Action, content
}
markdown, err := markdown.RenderString(markdownCtx, content)
if err != nil {
- return templates.Str2html(content) // old code did so: use Str2html to render in tmpl
+ return templates.SanitizeHTML(content) // old code did so: use SanitizeHTML to render in tmpl
}
return markdown
}
@@ -243,7 +243,7 @@ func feedActionsToFeedItems(ctx *context.Context, actions activities_model.Actio
}
}
if len(content) == 0 {
- content = templates.Str2html(desc)
+ content = templates.SanitizeHTML(desc)
}
items = append(items, &feeds.Item{